@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2006 by Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2006/03/01, v3.000.006, create_countries.sql
+# 2006/04/xx, v3.000.007, create_countries.sql
 # ---------------------------------------------------------------------------------------------------------
 
 create database if not exists `asnmtap`;
